scheduler

package
v1.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Backend

type Backend interface {
	LoadJobs() ([]types.CronJob, error)
	SaveJobs(cfg config.Config, jobs []types.CronJob) error
	CreateBackup(cfg config.Config) (string, error)
	ListBackups(cfg config.Config) ([]types.Backup, error)
	RestoreBackup(cfg config.Config, filename string) error
	RemoveAll(cfg config.Config) error
	RunNow(id int) ([]byte, error)
	ValidateManagedSchedule(expr string) error
}

Backend abstracts job storage and execution across supported schedulers.

func DefaultBackend

func DefaultBackend(cfg config.Config) Backend

DefaultBackend selects the platform backend for the current runtime.

func NewBackend

func NewBackend(goos string, cfg config.Config) Backend

NewBackend selects the platform backend for the requested OS.

type PowerShellRunner

type PowerShellRunner interface {
	Run(script string) ([]byte, error)
}

Jump to