Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Backend ¶
type Backend interface {
LoadJobs() ([]types.CronJob, error)
SaveJobs(cfg config.Config, jobs []types.CronJob) error
CreateBackup(cfg config.Config) (string, error)
ListBackups(cfg config.Config) ([]types.Backup, error)
RestoreBackup(cfg config.Config, filename string) error
RemoveAll(cfg config.Config) error
RunNow(id int) ([]byte, error)
ValidateManagedSchedule(expr string) error
}
Backend abstracts job storage and execution across supported schedulers.
func DefaultBackend ¶
DefaultBackend selects the platform backend for the current runtime.
type PowerShellRunner ¶
Click to show internal directories.
Click to hide internal directories.